@@ -674,7 +674,7 @@ void KViewSearchLineWidget::createWidgets()
     d->layout->setMargin(0);
 
     QLabel *label = new QLabel(i18n("S&earch:"));
-    label->setObjectName( QLatin1String("kde toolbar widget" ));
+    label->setObjectName( QStringLiteral("kde toolbar widget" ));
     d->layout->addWidget(label);
 
     d->searchLine = createSearchLine(d->view);
